#
# spec file for package fcitx5-skk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%global sname fcitx5-skk
%if "%{flavor}" == ""
%global pname %sname
%else
%global pname %{sname}-%{flavor}
%endif

Name:           %{pname}
Version:        5.1.6
Release:        1.2
Summary:        Libskk input method engine for Fcitx5
License:        GPL-3.0-or-later
Group:          System/I18n/Japanese
URL:            https://github.com/fcitx/fcitx5-skk
Source:         https://download.fcitx-im.org/fcitx5/%{sname}/%{sname}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  fcitx5-qt-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libskk-devel
BuildRequires:  pkgconfig
%if "%{flavor}" == ""
BuildRequires:  libqt5-qtbase-devel
Conflicts:      %{sname}-qt6
Provides:       fcitx-skk = %{version}
Obsoletes:      fcitx-skk <= 0.1.4
%endif
%if "%{flavor}" == "qt6"
BuildRequires:  qt6-base-devel
Conflicts:      %{sname}
Supplements:    (fcitx5 and skkdic and plasma6-workspace)
%endif
BuildRequires:  zstd
Requires:       fcitx5
%if 0%{?suse_version} <= 1520
BuildRequires:  appstream-glib-devel
%endif

%description
fcitx-skk is an input method engine for Fcitx, which uses libskk as its backend.

%prep
%setup -q -n %{sname}-%{version}

%build
%if "%{flavor}" == "qt6"
%if 0%{?suse_version} == 1500
%cmake -DCMAKE_CXX_COMPILER=%{_bindir}/g++-13
%else
%cmake
%endif
%endif
%if "%{flavor}" == ""
%cmake -DUSE_QT6=OFF
%endif
%make_build

%install
%cmake_install
%find_lang %{sname}

%files -f %{sname}.lang
%license LICENSES
%doc README.md
%{_fcitx5_libdir}/skk.so
%if "%{flavor}" == ""
%{_fcitx5_qt5dir}/libfcitx5-skk-config.so
%endif
%if "%{flavor}" == "qt6"
%{_libdir}/fcitx5/qt6/libfcitx5-skk-config.so
%endif
%{_fcitx5_addondir}/skk.conf
%{_fcitx5_imconfdir}/skk.conf
%{_fcitx5_datadir}/skk
%{_datadir}/icons/hicolor/*/apps/fcitx_skk*
%{_datadir}/icons/hicolor/*/apps/org.fcitx.Fcitx5.fcitx_skk*
%{_datadir}/metainfo/org.fcitx.Fcitx5.Addon.Skk.metainfo.xml

%changelog
* Wed Jan 29 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.6
  * use addon factory v2
* Sat Jan 11 2025 Marguerite Su <i@marguerite.su>
- fix leap 15.6 build
  * use g++-13 to workaround the <filesystem> include error
* Sun Jan  5 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.5
  * translation update
- changes in 5.1.4
  * Rename icons to avoid XDG icon name fallback with breeze icon theme
* Thu May 23 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.3
  * Update preedit when commit after mode change
- changes in 5.1.2
  * Use Qt6 by default
* Mon Feb  5 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.1
  * Port to Qt 6
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.0
  * translation update
* Mon May 22 2023 Marguerite Su <i@marguerite.su>
- Update to 5.0.15
  * add all size of icon
* Sun Nov 20 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.14
  * Update translation
* Tue Jul  5 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.13
  * Update translation
* Sun Mar 13 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.11
  * Set size policy so it can be same width when it's text label
  * Add label to text property
* Wed Dec 15 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.9
  * the surrounding text should be text() instead of selectedText()
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.6
  * update translation
- changes in version 5.0.5
  * Implement sub mode label
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.4
  * show mode information if the input mode is changed.
* Sun Jan 31 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.3
  * Make label in UI more meaningful
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.2
* Tue Nov 10 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.0
* Fri Sep  4 2020 Marguerite Su <i@marguerite.su>
- initial package
